==> jmb.jadmin-0.9.3.tar.gz: jmb.jadmin-0.9.3/jmb/jadmin/static/jmb/js/jmb.jadmin.js <==
//NAME space di jmb
if (window.jmb == undefined) window.jmb = {};

// vedi jmb.i18n.view
jmb.i18n_fix = function(c){

	if (jmb.catalog == undefined) jmb.catalog = [];
		if(typeof(django)!="undefined"){
			if(django.catalog){
				c = (c) ? c: django.catalog
				jmb.catalog.push(c)
				$.each(jmb.catalog, function(){
					django.catalog = $.extend(django.catalog, this);
				})
			}
		}
		if(typeof(catalog)!="undefined"){
			if(catalog){
				c = (c) ? c: catalog
				jmb.catalog.push(c)
				$.each(jmb.catalog, function(){
					catalog = $.extend(catalog, this);
			})
		}
	}
}

/* --- jmb.extra_action_fields_init --- */
jmb.extra_action_fields_show = function(value){
	$(".extrafield").hide()
	$(".extrafield.action_"+value).show()
}

/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
jmb.extra_action_fields_init = function(){
	 $(function(){
		 $('select[name=action]').change(function(e){
			 var value = $('select[name=action]').val()
			 jmb.extra_action_fields_show(value)
		 });
		 jmb.extra_action_fields_show($('select[name=action]').val())
	 });
}

/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
// fissa a 10px la larghezza delle colonne edit/delete nella change-list
jmb.fix_width_edit_delete = function () {
    $(function(){
        $("[field=v], [field=e], [field=d]").parent("th").width("10px").css("textAlign","center")
    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
//nasconde i campi nascosti nella change-form, che hanno name initial
jmb.hide_input = function () {
    $(function(){
    	 $(".form-row div input[type=hidden]:not([name*='initial'])").parent("div").hide()
    	//$(".form-row div input[type=hidden]:not([name*='initial'])").parents(".form-row").hide()
    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
//funzione per le admin tab, colora di rosso se sono presenti errori e apre la tab giusta
jmb.error_tab = function () {
     $(function(){
        $(".admintab-content .tab-pane").each(function(){
            var errors = $(this).find(".errors").length
            var errorslist = $(this).find(".errorlist li").length
            if(errors || errorslist){
                $("a[href='#"+  $(this).attr("id")+"']").addClass("taberror")
                $("a[href='#"+  $(this).attr("id")+"']").append('<span class="badge badge-important">'+ (errors || errorslist) +'</span>')
            }
        })
     });

}

//funzione per le admintab per averle sempre fisse in alto anche se si scorre
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
jmb.stickytab = function () {
    $(function(){
        //https://github.com/garand/sticky
        $(".stickytab").sticky({topSpacing:1, bottomSpacing:1});
    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
//i link con classe iframe vengo aperti nel popup, e possibile avere una funzione di callback
jmb.iframe_hjson_link = function (callback) {
	if(typeof(callback) == "undefined") callback  = function(){}
    $(document).on("click", ".iframe", function () {
    	jmb.last_link = this
        link = $(this).attr("href")
	if (link.indexOf('?') < 0) {
           link += '?'
        } else {
           link += '&'
        }
    	origin = ($("body").hasClass("change-form")) ? "&_origin=change-form" : ""
    	origin = ($("body").hasClass("change-list")) ? "&_origin=change-list" : ""
        if ($(this).hasClass("hjson")) link += "_hjson=1&_popup=1" + origin;
    	if ($(this).hasClass("refresh")) link += "&_refresh=1";
        var title = $(this).attr("title")
        var width = $(this).attr("width")
        var height = $(this).attr("height")
        jmb.show_in_popup(link, title, width, height,callback)
        return false;
    });

}
//funzionalità per il multi autocomplete, ora anche per tabularinline
// e per aggiungi con il + in popup
var iframe_callback_bk; var last_add_click; var last_added_pk;

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
jmb.autocomplete_filterby_patch = function () {
	jQuery(document).ready(function($) {
		iframe_callback_bk = iframe_callback
		$(".autocomplete-add-another").each(function(){
			$(this).insertAfter($(this).parent())
		})
		$(".autocomplete-add-another").on("click",function(){
			last_add_click = this
			href = $(this).attr("href") + "&_hjson=1"
			if(last_added_pk) { href = href.replace("/add","/" + last_added_pk);last_added_pk = undefined }
			iframe_callback = function(action, model, pk, content, message, method){
				iframe_callback = iframe_callback_bk;
				jmb.add_message(model + " " + gettext("aggiunto"),'info')
				//autoselezione
				$(last_add_click).parent().find("select.value-select").html('<option value="'+pk+'" selected="selected">'+pk+'</option>')
				$(last_add_click).parent().find(".deck.div").html("<span class='div hilight' data-value='"+pk+"'><span style='display: inline;' class='remove div'>X</span>"+content+"</span>")
				$(last_add_click).parent().find("input.autocomplete").hide()

				if (method == "_json_continue"){
					$(dialog).dialog("close");
					last_added_pk = pk
					$(last_add_click).click()
					return false;
			    }
				if (method == "_json"){
					$(dialog).dialog("close");
					return false;
			    }

			}
			jmb.show_in_popup(href, function(){
			})
			return false;
		})
	})
    //compatibile with autocomplete2
    yourlabs.Autocomplete.prototype.makeXhr = function () {
//	jmb.set_autocomplete_data(this)
        this.xhr = $.ajax(this.url, {
            type: "GET",
            data: this.data,
            complete: $.proxy(this.fetchComplete, this)
        });
    }

}

// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.get_autocomplete_select_element = function(field_name){
    return $('.autocomplete-light-widget select[name$=' + field_name + ']');
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- jmb.initialize_dependant_from_main --- */
/* --- jmb.init_dependency --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.get_autocomplete_element_parents = function(element){
    return element.parents('.autocomplete-light-widget');
}

/* --- jmb.initialize_dependant_from_main --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.set_autocomplete_data = function (autocomplete, dependency_array) {
    var filter_key = dependency_array[0]  // passed to server get /?filter_key=
    var main_id = dependency_array[1]

    var filter = $(main_id).val()
    if (filter) {
        filter_value = filter[0]
        autocomplete.data[filter_key] = filter_value
    } else {
        delete autocomplete.data[filter_key]
    }
}

/* --- jmb.init_dependency --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.initialize_dependant_from_main = function(dependant_field_name, dependency_array){
    var select_elements = jmb.get_autocomplete_select_element(dependant_field_name)
    $(select_elements).each(function(){
        widget_element = jmb.get_autocomplete_element_parents($(this));
        var autocomplete = widget_element.yourlabsWidget().autocomplete;
        jmb.set_autocomplete_data(autocomplete, dependency_array);
    });
}

/* --- jmb.init_all_dependencies --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.init_dependency = function (select_main_id, select_dependant_id, dependency_array) {
    /*
        Init dependency of dependant based on main select on page load or on any select change.
    */

    // init util vars
    var main_field_name = select_main_id.replace('id_', '');
    var dependant_field_name = select_dependant_id.replace('id_', '');
    var main_selector_widget = '.autocomplete-light-widget select[name$=' + main_field_name + ']'
    var dependant_selector_data_input = "span[data-input-id='" + select_dependant_id + "-autocomplete']"
    // var main_is_selected = $('#' + select_main_id)[0].options.length > 0
    // var dependant_is_selected = $('#' + select_dependant_id)[0].options.length > 0

    // modify dependant autocomplete data. Necessary on page load case.
    jmb.initialize_dependant_from_main(dependant_field_name, dependency_array);

    // when main-widget change, event has intercepted:
    $('body').on('change', main_selector_widget, function() {

        // modify dependant autocomplete data. Necessary on change of object
        jmb.initialize_dependant_from_main(dependant_field_name, dependency_array);

        // delete old/staled choices from autocomplete box
        $(dependant_selector_data_input).empty()

        // deselect previous choice (dependent from no longer used main)
        var select_elements = jmb.get_autocomplete_select_element(dependant_field_name)
        $(select_elements).each(function(){
            var dependant_widget_element = jmb.get_autocomplete_element_parents($(this))
            var dependant_widget = dependant_widget_element.yourlabsWidget()
            var selector = dependant_widget.input.yourlabsAutocomplete().choiceSelector;
            var choice = $('#' + select_dependant_id + '-deck .remove').parents(selector);
            dependant_widget.deselectChoice(choice);
        });

        // remove empty staled choice, bug in some case.
        $('.yourlabs-autocomplete').each(function(){
            if ($(this)[0].childNodes.length == 0){
                $(this)[0].style.display = 'none';
            }
        });

    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
// dynamic autocomplete
jmb.init_all_dependencies = function () {
/*
    This function has called when page is load or (inline case) when a new inline is added.
    for each dependency in page if it has been processed (then is present in STATIC_FIELD_DEPENDENCIES_PROCESSED) do
    nothing, else a dependency is set with init_dependency function.
*/

    $(document).ready(function(){

        if (typeof STATIC_FIELD_DEPENDENCIES_PROCESSED  === 'undefined'){
            STATIC_FIELD_DEPENDENCIES_PROCESSED = [];
        }

        // each widget that have
        $("input[data-autocomplete-dependency-map]").each(function(){

            input_widget = $(this);
            var dependency_widget_id = input_widget.attr("id")
	        var dependency_map = $(this).data("autocomplete-dependency-map")
	        var dependency_map_string = JSON.stringify(dependency_map)
	        var root_inline_select_id = "id_"

            // check if inline case
            if ((dependency_widget_id.search(/([0-9])+/g) > -1) || (dependency_widget_id.search("__prefix__") > 1)) {
                // inline case
                var root_field_id = dependency_widget_id.split('-')[0]
                var inline_number = dependency_widget_id.split('-')[1]
                var inline_field = dependency_widget_id.split('-')[2]
                var root_inline_select_id = root_field_id + '-' + inline_number + '-';  // "id_address-XXX-" or "id_address-__prefix__-"
                var field_dependency_key = inline_field + '_' + inline_number;         // region_XXX
                if (STATIC_FIELD_DEPENDENCIES_PROCESSED.indexOf(field_dependency_key) >= 0){
                    // this case has been processed
                    return 0;
                } else {
                    STATIC_FIELD_DEPENDENCIES_PROCESSED.push(field_dependency_key);
                    var root_inline_select_id = dependency_widget_id.split('-')[0] + '-' + dependency_widget_id.split('-')[1] + '-'; // root_inline_select_id = "id_address-XXX-" or "id_address-__prefix__-"
                }

            }

            // init dependency_array
            var dependency_array = $.map(dependency_map, function(key, value) {
                var key = key.replace('id_', root_inline_select_id)
                // calculate select_main_id
                select_main_id = key.replace('#', '');
                return [value, key]; // value is main widget name, key is main id of widget
            });

            // calculate select_dependant_id
            var dependant_input_id = input_widget[0].getAttribute('id');
            var select_dependant_id = dependant_input_id.replace('-autocomplete', '');

            // register initDependency
            jmb.init_dependency(select_main_id, select_dependant_id, dependency_array);
        });
        $("#address_person-group").on( "click", "a", function() {
            jmb.init_all_dependencies();
        });
    })
}

jmb.auto_popup = function (classe,callback) {
	if (!(classe)) classe = 'a.iframe:not(.hjson)';
    jQuery(document).ready(function($) {
	    $(classe)
		    .click(
			    function() {
			        var src = $(this).attr("href")
			        suffix = (src.indexOf("?") !=-1) ?"&_popup=1" : "?_popup=1"
				    src+=  suffix
				    var title = $(this).attr("title")
				    var width = $(this).attr("width")
				    var height = $(this).attr("height")
				    jmb.show_in_popup(src, title, width, height,callback)
				    return false;
			    })
    })
}

/* --- jmb.autocomplete_filterby_patch --- */
//aggiunge un messaggio alla lista classe = {info|error}
//parametro add se true aggiunge alla lista, se false cancella tutto
jmb.add_message = function(text, classe,add){
	if($(".messagelist").length==0){
		$("#content").before('<ul class="messagelist"></ul>')
	}
	if(add){
		$(".messagelist").append('<li class="'+classe+'">'+ text +'</li>')
	}else{
		$(".messagelist").html('<li class="'+classe+'">'+ text +'</li>')
	}
}

/* --- jmb.iframe_hjson_link --- */
/* --- jmb.autocomplete_filterby_patch --- */
/* --- jmb.auto_popup --- */
//apre il popup
jmb.show_in_popup = function (src, title, width, height, callback) {
	if(typeof(callback) == "undefined") callback  = function(){}
    if (!(src)) return false;
    var title = title || " "
    var width = width || 1000
    var height = height || 500
    var iframe = $('<iframe id="popiframe" frameborder="0" marginwidth="0" marginheight="0" allowfullscreen></iframe>');

    dialog = $("<div></div>").append(iframe).appendTo("body")
    $(dialog).dialog({
        autoOpen: false,
        modal: true,
        resizable: true,
        width: "auto",
        height: "auto",
        close: function () {
            iframe.attr("src", "");
            callback()
        },
        open: function (event, ui) {
            iframe.attr({
                width: '100%',
                height: '90%'
            });
            iframe.parents(".ui-dialog").css(
                'width', width);
            $(".ui-dialog-content").css('overflow', 'hidden');


            $(".ui-dialog-titlebar-close").html("X")
            dialog.parent().height(parseInt(height) + 10)
            dialog.height(height)
        }
    });
    iframe.attr({
        width: +width,
        height: +height,
        src: src
    });
    $(dialog).dialog("option", "title", title)
    $(dialog).dialog("open");

    return true;
}

//funzione chiamata dal return delle pagine con hjson
jmb.iframe_callback = function(action, model, pk, content, message, method) {
    if (action == "change") {
        tr = $("<div></div>").append(content).find("tr")
        //aggiunge la checkbox e sostiutisce il tr con quello nuovo
        $(tr).prepend('<td class="action-checkbox"><input class="action-select" name="_selected_action" type="checkbox" value="'+pk+'"></td>')
        row = $(jmb.last_link).parents("tr")
        row.html(tr.html())
    }

    if (action == "add") {
       // da implementare in futuro
    }

    if (action == "delete") {
    	row = $(jmb.last_link).parents("tr")
        $(row).hide("slow", function() {
        	// ricolora blu e bianco le righe alternate
        	$(row).parents("tbody").find("tr:visible:even").addClass("row1").removeClass("row2")
        	$(row).parents("tbody").find("tr:visible:odd").addClass("row2").removeClass("row1")
        });

    }
    if(message){
    	//aggiunge il messaggio se presente
        if( $("ul.messagelist").length==0){
		    $(".breadcrumbs").after("<ul class='messagelist'></ul>")
	    }
	    $("ul.messagelist").html($("<li class='info'></li>").html(message))
	}
	if(typeof(dialog)!="undefined") dialog.dialog("close")

	if (method == "_json_continue"){
		//caso del salva e continua
		$(jmb.last_link).click()
    }
    if (method == "_addanother"){
    	row = $(jmb.last_link).parents("tr")
    	tr = $("<div></div>").append(content).find("tr")
        $(tr).prepend('<td class="action-checkbox"><input class="action-select" name="_selected_action" type="checkbox" value="'+pk+'"></td>')
    	$(row).after(tr);
    	$(row).parents("tbody").find("tr:visible:even").addClass("row1").removeClass("row2")
    	$(row).parents("tbody").find("tr:visible:odd").addClass("row2").removeClass("row1")
    }

}

iframe_callback = jmb.iframe_callback

==> jmb.jadmin-0.9.4.tar.gz: jmb.jadmin-0.9.4/jmb/jadmin/static/jmb/js/jmb.jadmin.js <==
//NAME space di jmb
if (window.jmb == undefined) window.jmb = {};

// vedi jmb.i18n.view
jmb.i18n_fix = function(c){

	if (jmb.catalog == undefined) jmb.catalog = [];
		if(typeof(django)!="undefined"){
			if(django.catalog){
				c = (c) ? c: django.catalog
				jmb.catalog.push(c)
				$.each(jmb.catalog, function(){
					django.catalog = $.extend(django.catalog, this);
				})
			}
		}
		if(typeof(catalog)!="undefined"){
			if(catalog){
				c = (c) ? c: catalog
				jmb.catalog.push(c)
				$.each(jmb.catalog, function(){
					catalog = $.extend(catalog, this);
			})
		}
	}
}

/* --- jmb.extra_action_fields_init --- */
jmb.extra_action_fields_show = function(value){
	$(".extrafield").hide()
	$(".extrafield.action_"+value).show()
}

/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
jmb.extra_action_fields_init = function(){
	 $(function(){
		 $('select[name=action]').change(function(e){
			 var value = $('select[name=action]').val()
			 jmb.extra_action_fields_show(value)
		 });
		 jmb.extra_action_fields_show($('select[name=action]').val())
	 });
}

/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
// fissa a 10px la larghezza delle colonne edit/delete nella change-list
jmb.fix_width_edit_delete = function () {
    $(function(){
        $("[field=v], [field=e], [field=d]").parent("th").width("10px").css("textAlign","center")
    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
//nasconde i campi nascosti nella change-form, che hanno name initial
jmb.hide_input = function () {
    $(function(){
    	 $(".form-row div input[type=hidden]:not([name*='initial'])").parent("div").hide()
    	//$(".form-row div input[type=hidden]:not([name*='initial'])").parents(".form-row").hide()
    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
//funzione per le admin tab, colora di rosso se sono presenti errori e apre la tab giusta
jmb.error_tab = function () {
     $(function(){
        $(".admintab-content .tab-pane").each(function(){
            var errors = $(this).find(".errors").length
            var errorslist = $(this).find(".errorlist li").length
            if(errors || errorslist){
                $("a[href='#"+  $(this).attr("id")+"']").addClass("taberror")
                $("a[href='#"+  $(this).attr("id")+"']").append('<span class="badge badge-important">'+ (errors || errorslist) +'</span>')
            }
        })
     });

}

//funzione per le admintab per averle sempre fisse in alto anche se si scorre
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
// jmb.stickytab = function () {
//     $(function(){
//         //https://github.com/garand/sticky
//         $(".stickytab").sticky({topSpacing:1, bottomSpacing:1});
//     });
// }

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- JMB.CORE:CHANGE_LIST.HTML --- */
/* --- JMB.ADMIN:CHANGE_FORM.HTML --- */
/* --- JMB.ADMIN:CHANGE_LIST.HTML --- */
//i link con classe iframe vengo aperti nel popup, e possibile avere una funzione di callback
jmb.iframe_hjson_link = function (callback) {
	if(typeof(callback) == "undefined") callback  = function(){}
    $(document).on("click", ".iframe", function () {
    	jmb.last_link = this
        link = $(this).attr("href")
	if (link.indexOf('?') < 0) {
           link += '?'
        } else {
           link += '&'
        }
    	origin = ($("body").hasClass("change-form")) ? "&_origin=change-form" : ""
    	origin = ($("body").hasClass("change-list")) ? "&_origin=change-list" : ""
        if ($(this).hasClass("hjson")) link += "_hjson=1&_popup=1" + origin;
    	if ($(this).hasClass("refresh")) link += "&_refresh=1";
        var title = $(this).attr("title")
        var width = $(this).attr("width")
        var height = $(this).attr("height")
        jmb.show_in_popup(link, title, width, height,callback)
        return false;
    });

}
//funzionalità per il multi autocomplete, ora anche per tabularinline
// e per aggiungi con il + in popup
var iframe_callback_bk; var last_add_click; var last_added_pk;

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
jmb.autocomplete_filterby_patch = function () {
	jQuery(document).ready(function($) {
		iframe_callback_bk = iframe_callback
		$(".autocomplete-add-another").each(function(){
			$(this).insertAfter($(this).parent())
		})
		$(".autocomplete-add-another").on("click",function(){
			last_add_click = this
			href = $(this).attr("href") + "&_hjson=1"
			if(last_added_pk) { href = href.replace("/add","/" + last_added_pk);last_added_pk = undefined }
			iframe_callback = function(action, model, pk, content, message, method){
				iframe_callback = iframe_callback_bk;
				jmb.add_message(model + " " + gettext("aggiunto"),'info')
				//autoselezione
				$(last_add_click).parent().find("select.value-select").html('<option value="'+pk+'" selected="selected">'+pk+'</option>')
				$(last_add_click).parent().find(".deck.div").html("<span class='div hilight' data-value='"+pk+"'><span style='display: inline;' class='remove div'>X</span>"+content+"</span>")
				$(last_add_click).parent().find("input.autocomplete").hide()

				if (method == "_json_continue"){
					$(dialog).dialog("close");
					last_added_pk = pk
					$(last_add_click).click()
					return false;
			    }
				if (method == "_json"){
					$(dialog).dialog("close");
					return false;
			    }

			}
			jmb.show_in_popup(href, function(){
			})
			return false;
		})
	})
    //compatibile with autocomplete2
    yourlabs.Autocomplete.prototype.makeXhr = function () {
//	jmb.set_autocomplete_data(this)
        this.xhr = $.ajax(this.url, {
            type: "GET",
            data: this.data,
            complete: $.proxy(this.fetchComplete, this)
        });
    }

}

// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.get_autocomplete_select_element = function(field_name){
    return $('.autocomplete-light-widget select[name^=' + field_name + ']');
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
/* --- jmb.initialize_dependant_from_main --- */
/* --- jmb.init_dependency --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.get_autocomplete_element_parents = function(element){
    return element.parents('.autocomplete-light-widget');
}

/* --- jmb.initialize_dependant_from_main --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.set_autocomplete_data = function (autocomplete, dependency_array) {
    var filter_key = dependency_array[0]  // passed to server get /?filter_key=
    var main_id = dependency_array[1]

    var filter = $(main_id).val()
    if (filter) {
        filter_value = filter[0]
        autocomplete.data[filter_key] = filter_value
    } else {
        delete autocomplete.data[filter_key]
    }
}

/* --- jmb.init_dependency --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.initialize_dependant_from_main = function(dependant_field_name, dependency_array){
    var select_elements = jmb.get_autocomplete_select_element(dependant_field_name)
    $(select_elements).each(function(){
        widget_element = jmb.get_autocomplete_element_parents($(this));
        var autocomplete = widget_element.yourlabsWidget().autocomplete;
        jmb.set_autocomplete_data(autocomplete, dependency_array);
    });
}

/* --- jmb.init_all_dependencies --- */
// dynamic autocomplete: used by jmb.init_all_dependencies
jmb.init_dependency = function (select_main_id, select_dependant_id, dependency_array) {
    /*
        Init dependency of dependant based on main select on page load or on any select change.
    */

    // init util vars
    var main_field_name = select_main_id.replace('id_', '');
    var dependant_field_name = select_dependant_id.replace('id_', '');
    var main_selector_widget = '.autocomplete-light-widget select[name^=' + main_field_name + ']'
    var dependant_selector_data_input = "span[data-input-id='" + select_dependant_id + "-autocomplete']"
    // var main_is_selected = $('#' + select_main_id)[0].options.length > 0
    // var dependant_is_selected = $('#' + select_dependant_id)[0].options.length > 0

    // modify dependant autocomplete data. Necessary on page load case.
    jmb.initialize_dependant_from_main(dependant_field_name, dependency_array);

    // when main-widget change, event has intercepted:
    $('body').on('change', main_selector_widget, function() {

        // modify dependant autocomplete data. Necessary on change of object
        jmb.initialize_dependant_from_main(dependant_field_name, dependency_array);

        // delete old/staled choices from autocomplete box
        $(dependant_selector_data_input).empty()

        // deselect previous choice (dependent from no longer used main)
        var select_elements = jmb.get_autocomplete_select_element(dependant_field_name)
        $(select_elements).each(function(){
            var dependant_widget_element = jmb.get_autocomplete_element_parents($(this))
            var dependant_widget = dependant_widget_element.yourlabsWidget()
            var selector = dependant_widget.input.yourlabsAutocomplete().choiceSelector;
            var choice = $('#' + select_dependant_id + '-deck .remove').parents(selector);
            dependant_widget.deselectChoice(choice);
        });

        // remove empty staled choice, bug in some case.
        $('.yourlabs-autocomplete').each(function(){
            if ($(this)[0].childNodes.length == 0){
                $(this)[0].style.display = 'none';
            }
        });

    });
}

/* --- JMB.CORE:CHANGE_FORM.HTML --- */
// dynamic autocomplete
jmb.init_all_dependencies = function () {
/*
    This function has called when page is load or (inline case) when a new inline is added.
    for each dependency in page if it has been processed (then is present in STATIC_FIELD_DEPENDENCIES_PROCESSED) do
    nothing, else a dependency is set with init_dependency function.
*/

    $(document).ready(function(){

        if (typeof STATIC_FIELD_DEPENDENCIES_PROCESSED  === 'undefined'){
            STATIC_FIELD_DEPENDENCIES_PROCESSED = [];
        }

        // each widget that have
        $("input[data-autocomplete-dependency-map]").each(function(){

            input_widget = $(this);
            var dependency_widget_id = input_widget.attr("id")
	        var dependency_map = $(this).data("autocomplete-dependency-map")
	        var dependency_map_string = JSON.stringify(dependency_map)
	        var root_inline_select_id = "id_"

            // check if inline case
            if ((dependency_widget_id.search(/([0-9])+/g) > -1) || (dependency_widget_id.search("__prefix__") > 1)) {
                // inline case
                var root_field_id = dependency_widget_id.split('-')[0]
                var inline_number = dependency_widget_id.split('-')[1]
                var inline_field = dependency_widget_id.split('-')[2]
                var root_inline_select_id = root_field_id + '-' + inline_number + '-';  // "id_address-XXX-" or "id_address-__prefix__-"
                var field_dependency_key = inline_field + '_' + inline_number;         // region_XXX
                if (STATIC_FIELD_DEPENDENCIES_PROCESSED.indexOf(field_dependency_key) >= 0){
                    // this case has been processed
                    return 0;
                } else {
                    STATIC_FIELD_DEPENDENCIES_PROCESSED.push(field_dependency_key);
                    var root_inline_select_id = dependency_widget_id.split('-')[0] + '-' + dependency_widget_id.split('-')[1] + '-'; // root_inline_select_id = "id_address-XXX-" or "id_address-__prefix__-"
                }

            }

            // init dependency_array
            var dependency_array = $.map(dependency_map, function(key, value) {
                var key = key.replace('id_', root_inline_select_id)
                // calculate select_main_id
                select_main_id = key.replace('#', '');
                return [value, key]; // value is main widget name, key is main id of widget
            });

            // calculate select_dependant_id
            var dependant_input_id = input_widget[0].getAttribute('id');
            var select_dependant_id = dependant_input_id.replace('-autocomplete', '');

            // register initDependency
            jmb.init_dependency(select_main_id, select_dependant_id, dependency_array);
        });
        $("#address_person-group").on( "click", "a", function() {
            jmb.init_all_dependencies();
        });
    })
}

jmb.auto_popup = function (classe,callback) {
	if (!(classe)) classe = 'a.iframe:not(.hjson)';
    jQuery(document).ready(function($) {
	    $(classe)
		    .click(
			    function() {
			        var src = $(this).attr("href")
			        suffix = (src.indexOf("?") !=-1) ?"&_popup=1" : "?_popup=1"
				    src+=  suffix
				    var title = $(this).attr("title")
				    var width = $(this).attr("width")
				    var height = $(this).attr("height")
				    jmb.show_in_popup(src, title, width, height,callback)
				    return false;
			    })
    })
}

/* --- jmb.autocomplete_filterby_patch --- */
//aggiunge un messaggio alla lista classe = {info|error}
//parametro add se true aggiunge alla lista, se false cancella tutto
jmb.add_message = function(text, classe,add){
	if($(".messagelist").length==0){
		$("#content").before('<ul class="messagelist"></ul>')
	}
	if(add){
		$(".messagelist").append('<li class="'+classe+'">'+ text +'</li>')
	}else{
		$(".messagelist").html('<li class="'+classe+'">'+ text +'</li>')
	}
}

/* --- jmb.iframe_hjson_link --- */
/* --- jmb.autocomplete_filterby_patch --- */
/* --- jmb.auto_popup --- */
//apre il popup
jmb.show_in_popup = function (src, title, width, height, callback) {
	if(typeof(callback) == "undefined") callback  = function(){}
    if (!(src)) return false;
    var title = title || " "
    var width = width || 1000
    var height = height || 500
    var iframe = $('<iframe id="popiframe" frameborder="0" marginwidth="0" marginheight="0" allowfullscreen></iframe>');

    dialog = $("<div></div>").append(iframe).appendTo("body")
    $(dialog).dialog({
        autoOpen: false,
        modal: true,
        resizable: true,
        width: "auto",
        height: "auto",
        close: function () {
            iframe.attr("src", "");
            callback()
        },
        open: function (event, ui) {
            iframe.attr({
                width: '100%',
                height: '90%'
            });
            iframe.parents(".ui-dialog").css(
                'width', width);
            $(".ui-dialog-content").css('overflow', 'hidden');


            $(".ui-dialog-titlebar-close").html("X")
            dialog.parent().height(parseInt(height) + 10)
            dialog.height(height)
        }
    });
    iframe.attr({
        width: +width,
        height: +height,
        src: src
    });
    $(dialog).dialog("option", "title", title)
    $(dialog).dialog("open");

    return true;
}

//funzione chiamata dal return delle pagine con hjson
jmb.iframe_callback = function(action, model, pk, content, message, method) {
    if (action == "change") {
        tr = $("<div></div>").append(content).find("tr")
        //aggiunge la checkbox e sostiutisce il tr con quello nuovo
        $(tr).prepend('<td class="action-checkbox"><input class="action-select" name="_selected_action" type="checkbox" value="'+pk+'"></td>')
        row = $(jmb.last_link).parents("tr")
        row.html(tr.html())
    }

    if (action == "add") {
       // da implementare in futuro
    }

    if (action == "delete") {
    	row = $(jmb.last_link).parents("tr")
        $(row).hide("slow", function() {
        	// ricolora blu e bianco le righe alternate
        	$(row).parents("tbody").find("tr:visible:even").addClass("row1").removeClass("row2")
        	$(row).parents("tbody").find("tr:visible:odd").addClass("row2").removeClass("row1")
        });

    }
    if(message){
    	//aggiunge il messaggio se presente
        if( $("ul.messagelist").length==0){
		    $(".breadcrumbs").after("<ul class='messagelist'></ul>")
	    }
	    $("ul.messagelist").html($("<li class='info'></li>").html(message))
	}
	if(typeof(dialog)!="undefined") dialog.dialog("close")

	if (method == "_json_continue"){
		//caso del salva e continua
		$(jmb.last_link).click()
    }
    if (method == "_addanother"){
    	row = $(jmb.last_link).parents("tr")
    	tr = $("<div></div>").append(content).find("tr")
        $(tr).prepend('<td class="action-checkbox"><input class="action-select" name="_selected_action" type="checkbox" value="'+pk+'"></td>')
    	$(row).after(tr);
    	$(row).parents("tbody").find("tr:visible:even").addClass("row1").removeClass("row2")
    	$(row).parents("tbody").find("tr:visible:odd").addClass("row2").removeClass("row1")
    }

}

iframe_callback = jmb.iframe_callback
